@@ -1,16 +1,16 @@
-import pytest
-from pytest_lazyfixture import lazy_fixture
-
-import numpy as np
-from numpy.testing import assert_allclose
 from typing import Union, List
 
+import pytest
+from pytest_lazyfixture import lazy_fixture
+import numpy as np
+from numpy.testing import assert_allclose
 import tensorflow as tf
 import tensorflow.keras as keras
+
 from alibi.explainers import CounterfactualRLTabular
 from alibi.explainers.backends.cfrl_base import get_hard_distribution
-from alibi.explainers.backends.cfrl_tabular import get_he_preprocessor, split_ohe, get_numerical_conditional_vector,\
-    get_categorical_conditional_vector, get_statistics, get_conditional_vector, sample
+from alibi.explainers.backends.cfrl_tabular import get_he_preprocessor, split_ohe, \
+    get_numerical_conditional_vector, get_categorical_conditional_vector, get_statistics, get_conditional_vector, sample
 
 
 @pytest.mark.parametrize('dataset', [lazy_fixture('iris_data'),
